==> kubernetes-model-networking-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IngressSpecBuilder extends io.fabric8.kubernetes.api.model.networking.v1.IngressSpecFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.IngressSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.networking.v1.IngressSpec,io.fabric8.kubernetes.api.model.networking.v1.IngressSpecBuilder>{
  public IngressSpecBuilder() {
    this(false);
  }
  public IngressSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new IngressSpec(), validationEnabled);
  }
  public IngressSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1.IngressSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1.IngressSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IngressSpec(), validationEnabled);
  }
  public IngressSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1.IngressSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1.IngressSpec instance) {
    this(fluent, instance, false);
  }
  public IngressSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1.IngressSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1.IngressSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDefaultBackend(instance.getDefaultBackend()); 
    fluent.withIngressClassName(instance.getIngressClassName()); 
    fluent.withRules(instance.getRules()); 
    fluent.withTls(instance.getTls()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IngressSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1.IngressSpec instance) {
    this(instance,false);
  }
  public IngressSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1.IngressSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDefaultBackend(instance.getDefaultBackend()); 
    this.withIngressClassName(instance.getIngressClassName()); 
    this.withRules(instance.getRules()); 
    this.withTls(instance.getTls()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.networking.v1.IngressSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.networking.v1.IngressSpec build() {
    IngressSpec buildable = new IngressSpec(fluent.getDefaultBackend(),fluent.getIngressClassName(),fluent.getRules(),fluent.getTls());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressSpecBuilder that = (IngressSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-networking-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IngressSpecBuilder extends IngressSpecFluentImpl<IngressSpecBuilder> implements VisitableBuilder<IngressSpec,IngressSpecBuilder>{
  public IngressSpecBuilder() {
    this(false);
  }
  public IngressSpecBuilder(Boolean validationEnabled) {
    this(new IngressSpec(), validationEnabled);
  }
  public IngressSpecBuilder(IngressSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressSpecBuilder(IngressSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IngressSpec(), validationEnabled);
  }
  public IngressSpecBuilder(IngressSpecFluent<?> fluent,IngressSpec instance) {
    this(fluent, instance, false);
  }
  public IngressSpecBuilder(IngressSpecFluent<?> fluent,IngressSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDefaultBackend(instance.getDefaultBackend()); 
    fluent.withIngressClassName(instance.getIngressClassName()); 
    fluent.withRules(instance.getRules()); 
    fluent.withTls(instance.getTls()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IngressSpecBuilder(IngressSpec instance) {
    this(instance,false);
  }
  public IngressSpecBuilder(IngressSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDefaultBackend(instance.getDefaultBackend()); 
    this.withIngressClassName(instance.getIngressClassName()); 
    this.withRules(instance.getRules()); 
    this.withTls(instance.getTls()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  IngressSpecFluent<?> fluent;
  Boolean validationEnabled;
  public IngressSpec build() {
    IngressSpec buildable = new IngressSpec(fluent.getDefaultBackend(),fluent.getIngressClassName(),fluent.getRules(),fluent.getTls());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
